/********************************
 Add messages to histories
 (c) 1999 Jeremy Wise
 GnomeICU
*********************************/

#ifndef __HISTADD_H__
#define __HISTADD_H__

void add_incoming_to_history( UIN_T uin, char *statement, time_t *timedate );
void add_outgoing_to_history( UIN_T uin, char *statement );

#endif /* __HISTADD_H__ */
